<?php

/**
 * @file Contains our drush command to load and unload fixtures
 *
 * @command fixtures-load
 *  Load all enabled fixtures that are currently installed
 *
 * @command fixtures-unload
 *  Unload all enabled fixtures that are currently installed.
 *  Every fixture should be able to revert the content it added
 *
 * @command fixtures-reload
 *  Unloads, and then loads all enabled fixtures currently installed
 */

/**
 * Implements hook_drush_command().
 */
function fixtures_drush_command() {
  $items = array();

  $items['fixtures-load'] = [
    'description' => 'Load all enabled fixtures that are currently installed',
    'drupal dependencies' => ['fixtures'],
    'aliases' => ['fixtures:load'],
  ];

  $items['fixtures-unload'] = [
    'description' => 'Unload all enabled fixtures that are currently installed.',
    'drupal dependencies' => ['fixtures'],
    'aliases' => ['fixtures:unload'],
  ];

  $items['fixtures-reload'] = [
    'description' => 'Reload (unload + load) all enabled fixtures that are currently installed',
    'drupal dependencies' => ['fixtures'],
    'aliases' => ['fixtures:reload'],
  ];

  return $items;
}

/**
 * Call back function for fixtures-load
 */
function drush_fixtures_fixtures_load() {
  /** @var \Drupal\fixtures\FixturesManager $fixturesManager */
  $fixturesManager = Drupal::service('fixtures');
  foreach ($fixturesManager->getGenerators() as $generator) {
    drush_print('Loading: ' . get_class($generator));
    $generator->load();
  }
}

/**
 * Call back function for fixtures-load
 */
function drush_fixtures_fixtures_unload() {
  /** @var \Drupal\fixtures\FixturesManager $fixturesManager */
  $fixturesManager = Drupal::service('fixtures');
  foreach ($fixturesManager->getGenerators(true) as $generator) {
    drush_print('Unloading: ' . get_class($generator));
    $generator->unLoad();
  }
}

/**
 * Call back function for fixtures-load
 */
function drush_fixtures_fixtures_reload() {
  drush_fixtures_fixtures_unload();
  drush_fixtures_fixtures_load();
}
